@@ -177,36 +177,64 @@ QString GettextStorage::target(const DocPosition& pos) const
 {
     return m_entries.at(pos.entry).msgstr(pos.form);
 }
-QString GettextStorage::sourceWithPlurals(const DocPosition& pos) const
+QString GettextStorage::sourceWithPlurals(const DocPosition& pos, bool truncateFirstLine) const
 {
     if (m_entries.at(pos.entry).isPlural()) {
         const QVector<QString> plurals = m_entries.at(pos.entry).msgidPlural();
         QString pluralString;
         for (int i = 0; i < plurals.size(); i++) {
-            pluralString += plurals.at(i);
+            QString str = plurals.at(i);
+            if (truncateFirstLine)
+            {
+                int truncatePos = str.indexOf("\n");
+                if (truncatePos != -1)
+                    str.truncate(truncatePos);
+            }
+            pluralString += str;
             if (i != plurals.size() - 1) {
                 pluralString += '|';
             }
         }
         return pluralString;
     } else {
-        return m_entries.at(pos.entry).msgid(pos.form);
+        QString str = m_entries.at(pos.entry).msgid(pos.form);
+        if (truncateFirstLine)
+        {
+            int truncatePos = str.indexOf("\n");
+            if (truncatePos != -1)
+                str.truncate(truncatePos);
+        }
+        return str;
     }
 }
-QString GettextStorage::targetWithPlurals(const DocPosition& pos) const
+QString GettextStorage::targetWithPlurals(const DocPosition& pos, bool truncateFirstLine) const
 {
     if (m_entries.at(pos.entry).isPlural()) {
         const QVector<QString> plurals = m_entries.at(pos.entry).msgstrPlural();
         QString pluralString;
         for (int i = 0; i < plurals.size(); i++) {
-            pluralString += plurals.at(i);
+            QString str = plurals.at(i);
+            if (truncateFirstLine)
+            {
+                int truncatePos = str.indexOf("\n");
+                if (truncatePos != -1)
+                    str.truncate(truncatePos);
+            }
+            pluralString += str;
             if (i != plurals.size() - 1) {
                 pluralString += '|';
             }
         }
         return pluralString;
     } else {
-        return m_entries.at(pos.entry).msgstr(pos.form);
+        QString str = m_entries.at(pos.entry).msgstr(pos.form);
+        if (truncateFirstLine)
+        {
+            int truncatePos = str.indexOf("\n");
+            if (truncatePos != -1)
+                str.truncate(truncatePos);
+        }
+        return str;
     }
 }
 
