@@ -84,7 +84,7 @@ static const langPInfo langsWithPInfo[] = {
     { "hsb", "nplurals=4; plural=n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3;" },
     { "hu", "nplurals=2; plural=(n != 1);" },
     { "hy", "nplurals=4; plural=n==1 ? 3 : n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;" },
-    { "id", "nplurals=1; plural=0;" },
+    { "id", "nplurals=2; plural=(n != 1);" },
     { "it", "nplurals=2; plural=(n != 1);" },
     { "ja", "nplurals=1; plural=0;" },
     { "ka", "nplurals=1; plural=0;" },
