@@ -159,7 +159,7 @@ QVariant CatalogTreeModel::data(const QModelIndex& index, int role) const
         if (index.column() >= TranslationStatus)
             return QVariant();
         else if (index.column() == Source || index.column() == Target) {
-            QString str = index.column() == Source ? m_catalog->msgidWithPlurals(index.row()) : m_catalog->msgstrWithPlurals(index.row());
+            QString str = index.column() == Source ? m_catalog->msgidWithPlurals(index.row(), false) : m_catalog->msgstrWithPlurals(index.row(), false);
             return m_ignoreAccel ? str.remove(Project::instance()->accel()) : str;
         }
         role = Qt::DisplayRole;
@@ -172,9 +172,9 @@ QVariant CatalogTreeModel::data(const QModelIndex& index, int role) const
     switch (index.column()) {
     case Key:    return index.row() + 1;
     case Source:
-        return m_catalog->msgidWithPlurals(index.row());
+        return m_catalog->msgidWithPlurals(index.row(), true);
     case Target:
-        return m_catalog->msgstrWithPlurals(index.row());
+        return m_catalog->msgstrWithPlurals(index.row(), true);
     case Notes: {
         QString result;
         foreach (const Note &note, m_catalog->notes(index.row()))
