@@ -8,7 +8,7 @@
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy 
+  by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -37,11 +37,16 @@ class MultiEditorAdaptor: public EditorAdaptor
 {
     Q_OBJECT
 public:
-    MultiEditorAdaptor(EditorTab *parent);
-    ~MultiEditorAdaptor() { /*qCWarning(LOKALIZE_LOG)<<"bye bye cruel world";*/ }
+    explicit MultiEditorAdaptor(EditorTab *parent);
+    ~MultiEditorAdaptor()
+    {
+        /*qCWarning(LOKALIZE_LOG)<<"bye bye cruel world";*/
+    }
 
     inline EditorTab* editorTab() const
-    { return static_cast<EditorTab*>(QObject::parent()); }
+    {
+        return static_cast<EditorTab*>(QObject::parent());
+    }
 
     void setEditorTab(EditorTab* e);
 
