@@ -8,7 +8,7 @@
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy 
+  by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -46,7 +46,6 @@
 #include <QFileInfo>
 #include <QStringBuilder>
 
-#ifndef NOKDE
 #include "projectmodel.h"
 #include "webquerycontroller.h"
 
@@ -62,36 +61,35 @@
 
 #include <QDBusArgument>
 using namespace Kross;
-#endif
 
 QString getMailingList()
 {
     QString lang = QLocale::system().name();
-    if(lang.startsWith(QLatin1String("ca")))
+    if (lang.startsWith(QLatin1String("ca")))
         return QLatin1String("kde-i18n-ca@kde.org");
-    if(lang.startsWith(QLatin1String("de")))
+    if (lang.startsWith(QLatin1String("de")))
         return QLatin1String("kde-i18n-de@kde.org");
-    if(lang.startsWith(QLatin1String("hu")))
+    if (lang.startsWith(QLatin1String("hu")))
         return QLatin1String("kde-l10n-hu@kde.org");
-    if(lang.startsWith(QLatin1String("tr")))
+    if (lang.startsWith(QLatin1String("tr")))
         return QLatin1String("kde-l10n-tr@kde.org");
-    if(lang.startsWith(QLatin1String("it")))
+    if (lang.startsWith(QLatin1String("it")))
         return QLatin1String("kde-i18n-it@kde.org");
-    if(lang.startsWith(QLatin1String("lt")))
+    if (lang.startsWith(QLatin1String("lt")))
         return QLatin1String("kde-i18n-lt@kde.org");
-    if(lang.startsWith(QLatin1String("nb")))
+    if (lang.startsWith(QLatin1String("nb")))
         return QLatin1String("i18n-nb@lister.ping.uio.no");
-    if(lang.startsWith(QLatin1String("nl")))
+    if (lang.startsWith(QLatin1String("nl")))
         return QLatin1String("kde-i18n-nl@kde.org");
-    if(lang.startsWith(QLatin1String("nn")))
+    if (lang.startsWith(QLatin1String("nn")))
         return QLatin1String("i18n-nn@lister.ping.uio.no");
-    if(lang.startsWith(QLatin1String("pt_BR")))
+    if (lang.startsWith(QLatin1String("pt_BR")))
         return QLatin1String("kde-i18n-pt_BR@kde.org");
-    if(lang.startsWith(QLatin1String("ru")))
+    if (lang.startsWith(QLatin1String("ru")))
         return QLatin1String("kde-russian@lists.kde.ru");
-    if(lang.startsWith(QLatin1String("se")))
+    if (lang.startsWith(QLatin1String("se")))
         return QLatin1String("i18n-sme@lister.ping.uio.no");
-    if(lang.startsWith(QLatin1String("sl")))
+    if (lang.startsWith(QLatin1String("sl")))
         return QLatin1String("lugos-slo@lugos.si");
 
     return QLatin1String("kde-i18n-doc@kde.org");
@@ -100,7 +98,7 @@ QString getMailingList()
 
 
 
-Project* Project::_instance=0;
+Project* Project::_instance = 0;
 void Project::cleanupProject()
 {
     delete Project::_instance; Project::_instance = 0;
@@ -108,9 +106,8 @@ void Project::cleanupProject()
 
 Project* Project::instance()
 {
-    if (_instance==0 )
-    {
-        _instance=new Project();
+    if (_instance == 0) {
+        _instance = new Project();
         qAddPostRoutine(Project::cleanupProject);
     }
     return _instance;
@@ -125,10 +122,10 @@ Project::Project()
     , m_tmManagerWindow(0)
 {
     setDefaults();
-/*
-    qRegisterMetaType<DocPosition>("DocPosition");
-    qDBusRegisterMetaType<DocPosition>();
-*/
+    /*
+        qRegisterMetaType<DocPosition>("DocPosition");
+        qDBusRegisterMetaType<DocPosition>();
+    */
     //QTimer::singleShot(66,this,SLOT(initLater()));
 }
 /*
@@ -154,34 +151,28 @@ Project::~Project()
 
 void Project::load(const QString &newProjectPath, const QString& forcedTargetLangCode, const QString& forcedProjectId)
 {
-    QTime a;a.start();
+    QTime a; a.start();
 
     TM::threadPool()->clear();
-    qCDebug(LOKALIZE_LOG)<<"loading"<<newProjectPath<<"finishing tm jobs...";
+    qCDebug(LOKALIZE_LOG) << "loading" << newProjectPath << "finishing tm jobs...";
 
-    if (!m_path.isEmpty())
-    {
-        TM::CloseDBJob* closeDBJob=new TM::CloseDBJob(projectID());
+    if (!m_path.isEmpty()) {
+        TM::CloseDBJob* closeDBJob = new TM::CloseDBJob(projectID());
         closeDBJob->setAutoDelete(true);
         TM::threadPool()->start(closeDBJob, CLOSEDB);
     }
     TM::threadPool()->waitForDone(500);//more safety
 
-#ifndef NOKDE
     setSharedConfig(KSharedConfig::openConfig(newProjectPath, KConfig::NoGlobals));
     if (!QFileInfo::exists(newProjectPath)) Project::instance()->setDefaults();
     ProjectBase::load();
-#else
-#endif
-    m_path=newProjectPath;
+    m_path = newProjectPath;
     m_desirablePath.clear();
 
     //cache:
-    m_projectDir=QFileInfo(m_path).absolutePath();
-#ifndef NOKDE
-    m_localConfig->setSharedConfig(KSharedConfig::openConfig(projectID()+QStringLiteral(".local"), KConfig::NoGlobals,QStandardPaths::DataLocation));
+    m_projectDir = QFileInfo(m_path).absolutePath();
+    m_localConfig->setSharedConfig(KSharedConfig::openConfig(projectID() + QStringLiteral(".local"), KConfig::NoGlobals, QStandardPaths::DataLocation));
     m_localConfig->load();
-#endif
 
     if (forcedTargetLangCode.length())
         setLangCode(forcedTargetLangCode);
@@ -208,12 +199,11 @@ void Project::load(const QString &newProjectPath, const QString& forcedTargetLan
 
 
     if (!isTmSupported())
-        qCWarning(LOKALIZE_LOG)<<"no sqlite module available";
+        qCWarning(LOKALIZE_LOG) << "no sqlite module available";
     //NOTE do we need to explicitly call it when project id changes?
     TM::DBFilesModel::instance()->openDB(projectID(), TM::Undefined, true);
 
-    if (QaModel::isInstantiated())
-    {
+    if (QaModel::isInstantiated()) {
         QaModel::instance()->saveRules();
         QaModel::instance()->loadRules(qaPath());
     }
@@ -226,7 +216,7 @@ void Project::load(const QString &newProjectPath, const QString& forcedTargetLan
 
 void Project::reinit()
 {
-    TM::CloseDBJob* closeDBJob=new TM::CloseDBJob(projectID());
+    TM::CloseDBJob* closeDBJob = new TM::CloseDBJob(projectID());
     closeDBJob->setAutoDelete(true);
     TM::threadPool()->start(closeDBJob, CLOSEDB);
 
@@ -246,15 +236,13 @@ QString Project::absolutePath(const QString& possiblyRelPath) const
 
 void Project::populateDirModel()
 {
-#ifndef NOKDE
-    if (Q_UNLIKELY( m_path.isEmpty() || !QFileInfo::exists(poDir()) ))
+    if (Q_UNLIKELY(m_path.isEmpty() || !QFileInfo::exists(poDir())))
         return;
 
     QUrl potUrl;
     if (QFileInfo::exists(potDir()))
-        potUrl=QUrl::fromLocalFile(potDir());
+        potUrl = QUrl::fromLocalFile(potDir());
     model()->setUrl(QUrl::fromLocalFile(poDir()), potUrl);
-#endif
 }
 
 void Project::populateGlossary()
@@ -273,12 +261,12 @@ GlossaryNS::GlossaryWindow* Project::defineNewTerm(QString en, QString target)
         return 0;
 
     if (!m_glossaryWindow)
-        m_glossaryWindow=new GlossaryNS::GlossaryWindow(SettingsController::instance()->mainWindowPtr());
+        m_glossaryWindow = new GlossaryNS::GlossaryWindow(SettingsController::instance()->mainWindowPtr());
     m_glossaryWindow->show();
     m_glossaryWindow->activateWindow();
-    if (!en.isEmpty()||!target.isEmpty())
-        m_glossaryWindow->newTermEntry(en,target);
-    
+    if (!en.isEmpty() || !target.isEmpty())
+        m_glossaryWindow->newTermEntry(en, target);
+
     return m_glossaryWindow;
 }
 
@@ -286,32 +274,43 @@ bool Project::queryCloseForAuxiliaryWindows()
 {
     if (m_glossaryWindow && m_glossaryWindow->isVisible())
         return m_glossaryWindow->queryClose();
-    
+
     return true;
 }
 
 bool Project::isTmSupported() const
 {
-    QStringList drivers=QSqlDatabase::drivers();
+    QStringList drivers = QSqlDatabase::drivers();
     return drivers.contains(QLatin1String("QSQLITE"));
 }
 
 void Project::showTMManager()
 {
-    if (!m_tmManagerWindow)
-    {
-        if (!isTmSupported())
-        {
-            KMessageBox::information(0, i18n("TM facility requires SQLite Qt module."), i18n("No SQLite module available"));
+    if (!m_tmManagerWindow) {
+        if (!isTmSupported()) {
+            KMessageBox::information(nullptr, i18n("TM facility requires SQLite Qt module."), i18n("No SQLite module available"));
             return;
         }
 
-        m_tmManagerWindow=new TM::TMManagerWin(SettingsController::instance()->mainWindowPtr());
+        m_tmManagerWindow = new TM::TMManagerWin(SettingsController::instance()->mainWindowPtr());
     }
     m_tmManagerWindow->show();
     m_tmManagerWindow->activateWindow();
 }
 
+bool Project::isFileMissing(const QString& filePath) const
+{
+    if (!QFile::exists(filePath) && isLoaded()) {
+        //check if we are opening template
+        QString newPath = filePath;
+        newPath.replace(poDir(), potDir());
+        if (!QFile::exists(newPath) && !QFile::exists(newPath += 't')) {
+            return true;
+        }
+    }
+    return false;
+}
+
 void Project::save()
 {
     m_localConfig->setFirstRun(false);
@@ -323,14 +322,10 @@ void Project::save()
 
 ProjectModel* Project::model()
 {
-#ifndef NOKDE
     if (Q_UNLIKELY(!m_model))
-        m_model=new ProjectModel(this);
+        m_model = new ProjectModel(this);
 
     return m_model;
-#else
-    return 0;
-#endif
 }
 
 void Project::setDefaults()
@@ -343,12 +338,14 @@ void Project::init(const QString& path, const QString& kind, const QString& id,
                    const QString& sourceLang, const QString& targetLang)
 {
     setDefaults();
-    bool stop=false;
-    while(true)
-    {
-        setKind(kind);setSourceLangCode(sourceLang);setLangCode(targetLang);setProjectID(id);
+    bool stop = false;
+    while (true) {
+        setKind(kind); setSourceLangCode(sourceLang); setLangCode(targetLang); setProjectID(id);
         if (stop) break;
-        else {load(path);stop=true;}
+        else {
+            load(path);
+            stop = true;
+        }
     }
     save();
 }
@@ -357,27 +354,26 @@ void Project::init(const QString& path, const QString& kind, const QString& id,
 
 static void fillFilePathsRecursive(const QDir& dir, QMultiMap<QByteArray, QByteArray>& sourceFilePaths)
 {
-    QStringList subDirs(dir.entryList(QDir::Dirs|QDir::NoDotAndDotDot|QDir::Readable));
-    int i=subDirs.size();
-    while(--i>=0)
-        fillFilePathsRecursive(QDir(dir.filePath(subDirs.at(i))),sourceFilePaths);
+    QStringList subDirs(dir.entryList(QDir::Dirs | QDir::NoDotAndDotDot | QDir::Readable));
+    int i = subDirs.size();
+    while (--i >= 0)
+        fillFilePathsRecursive(QDir(dir.filePath(subDirs.at(i))), sourceFilePaths);
 
     static QStringList filters = QStringList(QStringLiteral("*.cpp"))
-                                           <<QStringLiteral("*.c")
-                                           <<QStringLiteral("*.cc")
-                                           <<QStringLiteral("*.mm")
-                                           <<QStringLiteral("*.ui")
-                                           <<QStringLiteral("*rc");
-    QStringList files(dir.entryList(filters, QDir::Files|QDir::NoDotAndDotDot|QDir::Readable));
-    i=files.size();
+                                 << QStringLiteral("*.c")
+                                 << QStringLiteral("*.cc")
+                                 << QStringLiteral("*.mm")
+                                 << QStringLiteral("*.ui")
+                                 << QStringLiteral("*rc");
+    QStringList files(dir.entryList(filters, QDir::Files | QDir::NoDotAndDotDot | QDir::Readable));
+    i = files.size();
 
-    QByteArray absDirPath=dir.absolutePath().toUtf8(); absDirPath.squeeze();
-    while(--i>=0)
-    {
+    QByteArray absDirPath = dir.absolutePath().toUtf8(); absDirPath.squeeze();
+    while (--i >= 0) {
         //qCDebug(LOKALIZE_LOG)<<files.at(i)<<absDirPath;
-        QByteArray fn=files.at(i).toUtf8(); fn.squeeze();
-        auto it=sourceFilePaths.constFind(fn);
-        if (it!=sourceFilePaths.constEnd())
+        QByteArray fn = files.at(i).toUtf8(); fn.squeeze();
+        auto it = sourceFilePaths.constFind(fn);
+        if (it != sourceFilePaths.constEnd())
             sourceFilePaths.insert(it.key(), absDirPath); //avoid having identical qbytearray objects to save memory
         else
             sourceFilePaths.insert(fn, absDirPath);
@@ -385,15 +381,18 @@ static void fillFilePathsRecursive(const QDir& dir, QMultiMap<QByteArray, QByteA
 }
 
 
-#ifndef NOKDE
 class SourceFilesSearchJob: public KJob
 {
 public:
-    SourceFilesSearchJob(const QString& folderName, QObject* parent=0);
-    void start();
-    void finish(){emitResult(); emit Project::instance()->sourceFilePathsAreReady();}
+    SourceFilesSearchJob(const QString& folderName, QObject* parent = nullptr);
+    void start() override;
+    void finish()
+    {
+        emitResult();
+        emit Project::instance()->sourceFilePathsAreReady();
+    }
 protected:
-    bool doKill();
+    bool doKill() override;
 
 private:
     QString m_folderName;
@@ -415,10 +414,10 @@ bool SourceFilesSearchJob::doKill()
 class FillSourceFilePathsJob: public QRunnable
 {
 public:
-    explicit FillSourceFilePathsJob(const QDir& dir, SourceFilesSearchJob* j):startingDir(dir),kj(j){}
+    explicit FillSourceFilePathsJob(const QDir& dir, SourceFilesSearchJob* j): startingDir(dir), kj(j) {}
 
 protected:
-    void run()
+    void run() override
     {
         QMultiMap<QByteArray, QByteArray> sourceFilePaths;
         fillFilePathsRecursive(startingDir, sourceFilePaths);
@@ -435,19 +434,15 @@ void SourceFilesSearchJob::start()
 {
     QThreadPool::globalInstance()->start(new FillSourceFilePathsJob(QDir(m_folderName), this));
     emit description(this,
-                i18n("Scanning folders with source files"),
-                qMakePair(i18n("Editor"), m_folderName));
+                     i18n("Scanning folders with source files"),
+                     qMakePair(i18n("Editor"), m_folderName));
 }
-#endif
 
 const QMultiMap<QByteArray, QByteArray>& Project::sourceFilePaths()
 {
-    if (m_sourceFilePaths.isEmpty())
-    {
+    if (m_sourceFilePaths.isEmpty()) {
         QDir dir(local()->sourceDir());
-        if (dir.exists())
-        {
-#ifndef NOKDE
+        if (dir.exists()) {
             SourceFilesSearchJob* metaJob = new SourceFilesSearchJob(local()->sourceDir());
             KIO::getJobTracker()->registerJob(metaJob);
             metaJob->start();
@@ -455,11 +450,6 @@ const QMultiMap<QByteArray, QByteArray>& Project::sourceFilePaths()
             //KNotification* notification=new KNotification("SourceFileScan", 0);
             //notification->setText( i18nc("@info","Please wait while %1 is being scanned for source files.", local()->sourceDir()) );
             //notification->sendEvent();
-#else
-            QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-            fillFilePathsRecursive(dir, m_sourceFilePaths);
-            QApplication::restoreOverrideCursor();
-#endif
         }
     }
     return m_sourceFilePaths;
@@ -473,37 +463,36 @@ const QMultiMap<QByteArray, QByteArray>& Project::sourceFilePaths()
 #include "languagelistmodel.h"
 void Project::projectOdfCreate()
 {
-    QString odf2xliff=QStringLiteral("odf2xliff");
-    if (QProcess::execute(odf2xliff, QStringList(QLatin1String("--version")))==-2)
-    {
+    QString odf2xliff = QStringLiteral("odf2xliff");
+    if (QProcess::execute(odf2xliff, QStringList(QLatin1String("--version"))) == -2) {
         KMessageBox::error(SettingsController::instance()->mainWindowPtr(), i18n("Install translate-toolkit package and retry"));
         return;
     }
 
-    QString odfPath=QFileDialog::getOpenFileName(SettingsController::instance()->mainWindowPtr(), QString(), QDir::homePath()/*_catalog->url().directory()*/,
-                                          i18n("OpenDocument files (*.odt *.ods)")/*"text/x-lokalize-project"*/);
+    QString odfPath = QFileDialog::getOpenFileName(SettingsController::instance()->mainWindowPtr(), QString(), QDir::homePath()/*_catalog->url().directory()*/,
+                      i18n("OpenDocument files (*.odt *.ods)")/*"text/x-lokalize-project"*/);
     if (odfPath.isEmpty())
         return;
 
-    QString targetLangCode=getTargetLangCode(QString(), true);
+    QString targetLangCode = getTargetLangCode(QString(), true);
 
     QFileInfo fi(odfPath);
-    QString trFolderName=i18nc("project folder name. %2 is targetLangCode", "%1 %2 Translation", fi.baseName(), targetLangCode);
+    QString trFolderName = i18nc("project folder name. %2 is targetLangCode", "%1 %2 Translation", fi.baseName(), targetLangCode);
     fi.absoluteDir().mkdir(trFolderName);
 
     QStringList args(odfPath);
     args.append(fi.absoluteDir().absoluteFilePath(trFolderName) % '/' % fi.baseName() % QLatin1String(".xlf"));
-    qCDebug(LOKALIZE_LOG)<<args;
+    qCDebug(LOKALIZE_LOG) << args;
     QProcess::execute(odf2xliff, args);
 
     if (!QFile::exists(args.at(1)))
         return;
-    
+
     emit closed();
 
-    Project::instance()->load(fi.absoluteDir().absoluteFilePath(trFolderName)+QLatin1String("/index.lokalize"), targetLangCode, fi.baseName()%'-'%targetLangCode);
+    Project::instance()->load(fi.absoluteDir().absoluteFilePath(trFolderName) + QLatin1String("/index.lokalize"), targetLangCode, fi.baseName() % '-' % targetLangCode);
 
-    emit fileOpenRequested(args.at(1));
+    emit fileOpenRequested(args.at(1), true);
 }
 
 
