@@ -36,20 +36,20 @@ class XliffHandler: public QXmlDefaultHandler
 {
 public:
     XliffHandler()
-     : total(0)
-     , untranslated(0)
-     , fuzzy(0)
-     , fuzzy_reviewer(0)
-     , fuzzy_approver(0)
-     , currentEntryFuzzy(false)
-     , currentEntryFuzzy_reviewer(false)
-     , currentEntryFuzzy_approver(false)
-     , charCount(0)
+        : total(0)
+        , untranslated(0)
+        , fuzzy(0)
+        , fuzzy_reviewer(0)
+        , fuzzy_approver(0)
+        , currentEntryFuzzy(false)
+        , currentEntryFuzzy_reviewer(false)
+        , currentEntryFuzzy_approver(false)
+        , charCount(0)
     {}
 
-    bool startElement(const QString& namespaceURI, const QString& localName, const QString& qName, const QXmlAttributes& atts);
-    bool endElement(const QString& namespaceURI, const QString& localName, const QString& qName);
-    bool characters(const QString&);
+    bool startElement(const QString& namespaceURI, const QString& localName, const QString& qName, const QXmlAttributes& atts) override;
+    bool endElement(const QString& namespaceURI, const QString& localName, const QString& qName) override;
+    bool characters(const QString&) override;
     //void endAnalysis(bool complete);
 
     int total;
@@ -61,10 +61,10 @@ public:
     QString lastTranslator;
     QString lastTranslator_fallback;
     QString lastDateString_fallback;
-        
+
 private:
     bool currentEntryFuzzy;
-    bool currentEntryFuzzy_reviewer; 
+    bool currentEntryFuzzy_reviewer;
     bool currentEntryFuzzy_approver;
     int charCount;
 };
@@ -74,29 +74,24 @@ TargetState stringToState(const QString& state);
 
 bool XliffHandler::startElement(const QString&, const QString& localName, const QString&, const QXmlAttributes& atts)
 {
-    //if (fileType == Unknown) 
+    //if (fileType == Unknown)
     //    fileType = strcmp(localname, "xliff") ? Other : XLF;
-    
-         if (localName==QLatin1String("source")) total++;
-    else if (localName==QLatin1String("target"))
-    {
-        charCount=0;
+
+    if (localName == QLatin1String("source")) total++;
+    else if (localName == QLatin1String("target")) {
+        charCount = 0;
 
         currentEntryFuzzy = currentEntryFuzzy_reviewer = currentEntryFuzzy_approver = false;
-        if (atts.value(QLatin1String("approved"))!=QLatin1String("yes"))
-        {
+        if (atts.value(QLatin1String("approved")) != QLatin1String("yes")) {
             QString state = atts.value(QLatin1String("state"));
-            if (state.length())
-            {
-                TargetState tstate=stringToState(state);
+            if (state.length()) {
+                TargetState tstate = stringToState(state);
                 currentEntryFuzzy = !::isApproved(tstate, ProjectLocal::Translator);
                 currentEntryFuzzy_reviewer = !::isApproved(tstate, ProjectLocal::Reviewer);
                 currentEntryFuzzy_approver = !::isApproved(tstate, ProjectLocal::Approver);
             }
         }
-    }
-    else if (localName==QLatin1String("phase"))
-    {
+    } else if (localName == QLatin1String("phase")) {
         QString contactNameString  = atts.value(QLatin1String("contact-name"));
         QString contactEmailString = atts.value(QLatin1String("contact-email"));
         QString dateString         = atts.value(QLatin1String("date"));
@@ -110,13 +105,11 @@ bool XliffHandler::startElement(const QString&, const QString& localName, const
             currentLastTranslator = contactEmailString;
 
         if (currentLastTranslator.length()) lastTranslator_fallback = currentLastTranslator;
-        if (dateString.length())
-        {
+        if (dateString.length()) {
             lastDateString_fallback = dateString;
 
             const QDate thisDate = QDate::fromString(dateString, Qt::ISODate);
-            if (lastDate.isNull() || thisDate >= lastDate) // >= Assuming the last one in the file is the real last one
-            {
+            if (lastDate.isNull() || thisDate >= lastDate) { // >= Assuming the last one in the file is the real last one
                 lastDate = thisDate;
                 lastTranslator = currentLastTranslator;
             }
@@ -126,26 +119,18 @@ bool XliffHandler::startElement(const QString&, const QString& localName, const
 }
 
 bool XliffHandler::endElement(const QString&, const QString& localName, const QString&)
-{    
-    if (localName==QLatin1String("target"))
-    {
-        if (!charCount)
-        {
+{
+    if (localName == QLatin1String("target")) {
+        if (!charCount) {
             ++untranslated;
-        }
-        else if (currentEntryFuzzy)
-        {
+        } else if (currentEntryFuzzy) {
             ++fuzzy;
             ++fuzzy_reviewer;
             ++fuzzy_approver;
-        }
-        else if (currentEntryFuzzy_reviewer)
-        {
+        } else if (currentEntryFuzzy_reviewer) {
             ++fuzzy_reviewer;
             ++fuzzy_approver;
-        }
-        else if (currentEntryFuzzy_approver)
-        {
+        } else if (currentEntryFuzzy_approver) {
             ++fuzzy_approver;
         }
     }
@@ -154,7 +139,7 @@ bool XliffHandler::endElement(const QString&, const QString& localName, const QS
 
 bool XliffHandler::characters(const QString& ch)
 {
-    charCount+=ch.length();
+    charCount += ch.length();
     return true;
 }
 
@@ -178,18 +163,18 @@ void XliffExtractor::extract(const QString& filePath, FileMetaData& m)
 
     //TODO WordCount
     m.fuzzy      = handler.fuzzy;
-    m.translated = handler.total-handler.untranslated-handler.fuzzy;
-    m.untranslated=handler.untranslated;
+    m.translated = handler.total - handler.untranslated - handler.fuzzy;
+    m.untranslated = handler.untranslated;
     m.filePath = filePath;
 
     //qCDebug(LOKALIZE_LOG)<<"parsed"<<filePath<<m.fuzzy<<m.translated<<m.untranslated<<handler.fuzzy_approver<<handler.fuzzy_reviewer;
-    Q_ASSERT(m.fuzzy>=0 && m.untranslated>=0 && handler.total>=0);
+    Q_ASSERT(m.fuzzy >= 0 && m.untranslated >= 0 && handler.total >= 0);
 
-    m.translated_approver=handler.total-handler.untranslated-handler.fuzzy_approver;
-    m.translated_reviewer=handler.total-handler.untranslated-handler.fuzzy_reviewer;
-    m.fuzzy_approver=handler.fuzzy_approver;
-    m.fuzzy_reviewer=handler.fuzzy_reviewer;
+    m.translated_approver = handler.total - handler.untranslated - handler.fuzzy_approver;
+    m.translated_reviewer = handler.total - handler.untranslated - handler.fuzzy_reviewer;
+    m.fuzzy_approver = handler.fuzzy_approver;
+    m.fuzzy_reviewer = handler.fuzzy_reviewer;
 
-    m.lastTranslator=handler.lastTranslator.length()?handler.lastTranslator:handler.lastTranslator_fallback;
-    m.translationDate=handler.lastDate.isValid()?handler.lastDate.toString(Qt::ISODate):handler.lastDateString_fallback;
+    m.lastTranslator = handler.lastTranslator.length() ? handler.lastTranslator : handler.lastTranslator_fallback;
+    m.translationDate = handler.lastDate.isValid() ? handler.lastDate.toString(Qt::ISODate) : handler.lastDateString_fallback;
 }
