@@ -8,7 +8,7 @@
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy 
+  by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -24,15 +24,15 @@
 #ifndef WIDGETTEXTCAPTURECONFIG_H
 #define WIDGETTEXTCAPTURECONFIG_H
 
-#include <KDialog>
+#include <QDialog>
 
 class Ui_WidgetTextCapture;
 
-class WidgetTextCaptureConfig: public KDialog
+class WidgetTextCaptureConfig: public QDialog
 {
     Q_OBJECT
 public:
-    explicit WidgetTextCaptureConfig(QWidget* parent = 0);
+    explicit WidgetTextCaptureConfig(QWidget* parent = nullptr);
     ~WidgetTextCaptureConfig();
 public slots:
     void writeConfig();
