@@ -38,26 +38,38 @@ class TranslationUnitTextEdit: public KTextEdit
 {
     Q_OBJECT
 public:
-    TranslationUnitTextEdit(Catalog* catalog, DocPosition::Part part, QWidget* parent=0);
+    explicit TranslationUnitTextEdit(Catalog* catalog, DocPosition::Part part, QWidget* parent = nullptr);
+    ~TranslationUnitTextEdit() override;
     //NOTE remove this when Qt is fixed (hack for unbreakable spaces bug #162016)
     QString toPlainText();
 
     ///@returns targetWithTags for the sake of not calling XliffStorage/doContent twice
-    CatalogString showPos(DocPosition pos, const CatalogString& refStr=CatalogString(), bool keepCursor=true);
-    DocPosition currentPos()const {return m_currentPos;}
+    CatalogString showPos(DocPosition pos, const CatalogString& refStr = CatalogString(), bool keepCursor = true);
+    DocPosition currentPos()const
+    {
+        return m_currentPos;
+    }
 
     void cursorToStart();
 
-    bool isSpellCheckingEnabled() const {return m_enabled;}
+    bool isSpellCheckingEnabled() const
+    {
+        return m_enabled;
+    }
     void setSpellCheckingEnabled(bool enable);
-    bool shouldBlockBeSpellChecked(const QString &block) const{Q_UNUSED(block); return true;}
+    void setVisualizeSeparators(bool enable);
+    bool shouldBlockBeSpellChecked(const QString &block) const override
+    {
+        Q_UNUSED(block);
+        return true;
+    }
 
 public slots:
     void reflectApprovementState();
     void reflectUntranslatedState();
 
-    bool removeTargetSubstring(int start=0, int end=-1, bool refresh=true);
-    void insertCatalogString(CatalogString catStr, int start=0, bool refresh=true);
+    bool removeTargetSubstring(int start = 0, int end = -1, bool refresh = true);
+    void insertCatalogString(CatalogString catStr, int start = 0, bool refresh = true);
 
     void source2target();
     void tagMenu();
@@ -70,21 +82,23 @@ public slots:
     void doExplicitCompletion();
 
 protected:
-    void keyPressEvent(QKeyEvent *keyEvent);
-    void keyReleaseEvent(QKeyEvent* e);
-    QMimeData* createMimeDataFromSelection() const;
-    void insertFromMimeData(const QMimeData* source);
-    void mouseReleaseEvent(QMouseEvent* event);
+    void keyPressEvent(QKeyEvent *keyEvent) override;
+    void keyReleaseEvent(QKeyEvent* e) override;
+    QMimeData* createMimeDataFromSelection() const override;
+    void insertFromMimeData(const QMimeData* source) override;
+    void mouseReleaseEvent(QMouseEvent* event) override;
+    void dropEvent(QDropEvent *event) override;
+    void dragEnterEvent(QDragEnterEvent *event) override;
 
-    void contextMenuEvent(QContextMenuEvent *event);
-    void wheelEvent(QWheelEvent *event);
-    bool event(QEvent *event);
+    void contextMenuEvent(QContextMenuEvent *event) override;
+    void wheelEvent(QWheelEvent *event) override;
+    bool event(QEvent *event) override;
 
 private:
     ///@a refStr is for proper numbering
-    void setContent(const CatalogString& catStr, const CatalogString& refStr=CatalogString());
+    void setContent(const CatalogString& catStr, const CatalogString& refStr = CatalogString());
 
-    int strForMicePosIfUnderTag(QPoint mice, CatalogString& str, bool tryHarder=false);
+    int strForMicePosIfUnderTag(QPoint mice, CatalogString& str, bool tryHarder = false);
 
     void requestToggleApprovement();
 
@@ -94,7 +108,7 @@ private:
 
 private slots:
     //for Undo/Redo tracking
-    void contentsChanged(int position,int charsRemoved,int charsAdded);
+    void contentsChanged(int position, int charsRemoved, int charsAdded);
     void completionActivated(const QString&);
     void fileLoaded();
 
@@ -121,7 +135,7 @@ signals:
     void tagInsertRequested(const InlineTag& tag);
 
     void binaryUnitSelectRequested(const QString&);
-    void tmLookupRequested(DocPosition::Part,const QString&);
+    void tmLookupRequested(DocPosition::Part, const QString&);
 
     void contentsModified(const DocPosition&);
     void approvedEntryDisplayed();
@@ -145,10 +159,14 @@ private:
     //for undo/redo tracking
     QString _oldMsgstr;
     QString _oldMsgstrAscii; //HACK to workaround #218246
+
+    //For text move with mouse
+    int m_cursorSelectionStart;
+    int m_cursorSelectionEnd;
 };
 
 
-void insertContent(QTextCursor& cursor, const CatalogString& catStr, const CatalogString& refStr=CatalogString(), bool insertText=true);
+void insertContent(QTextCursor& cursor, const CatalogString& catStr, const CatalogString& refStr = CatalogString(), bool insertText = true);
 
 
 #endif
